@@ -1,13 +1,11 @@
-
 from django.utils import unittest
-
+from django.utils import translation
 from django.template import Template, Context
 from pretty_times import pretty
-
-from datetime import datetime, timedelta
-
+from datetime import datetime, timedelta, tzinfo
 import operator
 
+
 class PrettyTimeTests(unittest.TestCase):
 
     def get_past_result(self, **kwargs):
@@ -32,12 +30,39 @@ class PrettyTimeTests(unittest.TestCase):
     def test_now(self):
         self.assertEqual("just now", self.apply_prettytime(datetime.today()))
 
+    def test_now_tz(self):
+        """test that non-naive datetimes are handled"""
+
+        class UTC(tzinfo):
+            """based on example tzinfo classes from:
+            http://docs.python.org/release/2.5.2/lib/datetime-tzinfo.html
+            """
+            def utcoffset(self, dt): return timedelta(0)
+            def dst(self, dt): return timedelta(0)
+
+        dt = datetime.utcnow().replace(tzinfo=UTC())
+        self.assertEqual("just now", self.apply_prettytime(dt))
+
     def test_ten_seconds_ago(self):
         self.assertEqual("10 seconds ago", self.get_past_result(seconds=10))
 
     def test_in_ten_seconds(self):
         self.assertEqual("in 10 seconds", self.get_future_result(seconds=10))
 
+    def test_french_in_ten_second(self):
+        try:
+            translation.activate('fr')
+            self.assertEqual("en 10 secondes", self.get_future_result(seconds=10))
+        finally:
+            translation.activate('en')
+
+    def test_french_ten_seconds_ago(self):
+        try:
+            translation.activate('fr')
+            self.assertEqual("ll ya 10 secondes", self.get_past_result(seconds=10))
+        finally:
+            translation.activate('en')
+
     def test_thirty_seconds_ago(self):
         self.assertEqual("30 seconds ago", self.get_past_result(seconds=30))
 
@@ -74,6 +99,18 @@ class PrettyTimeTests(unittest.TestCase):
     def test_tomorrow(self):
         self.assertEqual("tomorrow", self.get_future_result(days=1))
 
+    def test_next_week(self):
+        self.assertEqual("next week", self.get_future_result(days=8))
+
+    def test_two_weeks_ago(self):
+        self.assertEqual("2 weeks ago", self.get_past_result(days=15))
+
+    def test_in_two_weeks(self):
+        self.assertEqual("in 2 weeks", self.get_future_result(days=15))
+
+    def test_last_week(self):
+        self.assertEqual("last week", self.get_past_result(days=8))
+
     def test_two_days_ago(self):
         self.assertEqual("2 days ago", self.get_past_result(days=2))
 
@@ -110,6 +147,7 @@ class PrettyTimeTests(unittest.TestCase):
     def test_in_two_years(self):
         self.assertEqual("in 2 years", self.get_future_result(days=733))
 
+
 class PrettyTimeTemplateTagTests(PrettyTimeTests):
 
     def apply_prettytime(self, my_datetime):
